@@ -13,6 +13,14 @@ module Celluloid
       @proxy.method_missing(:method, @name).arity
     end
 
+    def name
+      @proxy.method_missing(:method, @name).name
+    end
+
+    def parameters
+      @proxy.method_missing(:method, @name).parameters
+    end
+
     def call(*args, &block)
       @proxy.__send__(@name, *args, &block)
     end
