@@ -1,12 +1,13 @@
 require 'set'
+
 require 'timers'
 
 module Celluloid
   # Allow methods to directly interact with the actor protocol
   class Receivers
-    def initialize
+    def initialize(timers)
       @receivers = Set.new
-      @timers = Timers.new
+      @timers = timers
     end
 
     # Receive an asynchronous message
@@ -28,24 +29,15 @@ module Celluloid
       end
     end
 
-    # How long to wait until the next timer fires
-    def wait_interval
-      @timers.wait_interval
-    end
-
-    # Fire any pending timers
-    def fire_timers
-      @timers.fire
-    end
-
     # Handle incoming messages
     def handle_message(message)
       receiver = @receivers.find { |r| r.match(message) }
       return unless receiver
 
       @receivers.delete receiver
-      @timers.cancel receiver.timer if receiver.timer
+      receiver.timer.cancel if receiver.timer
       receiver.resume message
+      message
     end
   end
 
