@@ -3,11 +3,11 @@ module Celluloid
   # accidentally do things to threads which have been returned to the pool,
   # such as, say, killing them
   class ThreadHandle
-    def initialize(role = nil)
+    def initialize(actor_system, role = nil)
       @mutex = Mutex.new
       @join  = ConditionVariable.new
 
-      @thread = Celluloid.internal_pool.get do
+      @thread = actor_system.get_thread do
         Thread.current.role = role
         begin
           yield
