@@ -1,5 +1,5 @@
 require 'spec_helper'
 
-describe Celluloid do
+describe Celluloid, actor_system: :global do
   it_behaves_like "a Celluloid Actor", Celluloid
 end
