@@ -1,6 +1,6 @@
 require 'spec_helper'
 
-describe Celluloid::SyncCall do
+describe Celluloid::SyncCall, actor_system: :global do
   class CallExampleActor
     include Celluloid
 
