@@ -1,6 +1,6 @@
 require 'spec_helper'
 
-describe "Celluloid.pool" do
+describe "Celluloid.pool", actor_system: :global do
   class ExampleError < StandardError; end
 
   class MyWorker
@@ -14,11 +14,23 @@ describe "Celluloid.pool" do
       end
     end
 
+    def sleepy_work
+      t = Time.now.to_f
+      sleep 0.25
+      t
+    end
+
     def crash
       raise ExampleError, "zomgcrash"
     end
   end
 
+  def test_concurrency_of(pool)
+    baseline = Time.now.to_f
+    values = 10.times.map { pool.future.sleepy_work }.map(&:value)
+    values.select {|t| t - baseline < 0.1 }.length
+  end
+
   subject { MyWorker.pool }
 
   it "processes work units synchronously" do
@@ -56,4 +68,25 @@ describe "Celluloid.pool" do
     end
     futures.map(&:value)
   end
+
+  context "#size=" do
+    subject { MyWorker.pool size: 4 }
+
+    it "should adjust the pool size up", pending: 'flaky' do
+      expect(test_concurrency_of(subject)).to eq(4)
+
+      subject.size = 6
+      subject.size.should == 6
+
+      test_concurrency_of(subject).should == 6
+    end
+
+    it "should adjust the pool size down" do
+      test_concurrency_of(subject).should == 4
+
+      subject.size = 2
+      subject.size.should == 2
+      test_concurrency_of(subject).should == 2
+    end
+  end
 end
