@@ -1,6 +1,6 @@
 require 'spec_helper'
 
-describe Celluloid::SupervisionGroup do
+describe Celluloid::SupervisionGroup, actor_system: :global do
   before :all do
     class MyActor
       include Celluloid
@@ -20,6 +20,20 @@ describe Celluloid::SupervisionGroup do
     Celluloid::Actor[:example].should be_running
   end
 
+  it "accepts a private actor registry" do
+    my_registry = Celluloid::Registry.new
+    MyGroup.run!(my_registry)
+    sleep 0.01
+
+    my_registry[:example].should be_running
+  end
+
+  it "removes actors from the registry when terminating" do
+    group = MyGroup.run!
+    group.terminate
+    Celluloid::Actor[:example].should be_nil
+  end
+
   context "pool" do
     before :all do
       class MyActor
@@ -41,5 +55,11 @@ describe Celluloid::SupervisionGroup do
       Celluloid::Actor[:example_pool].args.should eq ['foo']
       Celluloid::Actor[:example_pool].size.should be 3
     end
+
+    it "allows external access to the internal registry" do
+      supervisor = MyGroup.run!
+
+      supervisor[:example].should be_a MyActor
+    end
   end
 end
