@@ -1,5 +1,5 @@
 require 'spec_helper'
 
-describe Celluloid::TaskThread do
+describe Celluloid::TaskThread, actor_system: :within do
   it_behaves_like "a Celluloid Task", Celluloid::TaskThread
 end
