@@ -1,9 +1,13 @@
 require 'spec_helper'
 
 describe Celluloid::ThreadHandle do
+  let(:actor_system) do
+    Celluloid::ActorSystem.new
+  end
+
   it "knows thread liveliness" do
     queue = Queue.new
-    handle = Celluloid::ThreadHandle.new { queue.pop }
+    handle = Celluloid::ThreadHandle.new(actor_system) { queue.pop }
     handle.should be_alive
 
     queue << :die
@@ -13,10 +17,10 @@ describe Celluloid::ThreadHandle do
   end
 
   it "joins to thread handles" do
-    Celluloid::ThreadHandle.new { sleep 0.01 }.join
+    Celluloid::ThreadHandle.new(actor_system) { sleep 0.01 }.join
   end
 
   it "supports passing a role" do
-    Celluloid::ThreadHandle.new(:useful) { Thread.current.role.should == :useful }.join
+    Celluloid::ThreadHandle.new(actor_system, :useful) { Thread.current.role.should == :useful }.join
   end
 end
